# Ocelot

Ocelot is open source software for linking in life cycle assessment.

* [Homepage](https://ocelot.space)
* [Source code](https://github.com/OcelotProject/Ocelot)
* [Documentation](https://docs.ocelot.space/)
* Linux/OS X build status: [![Build Status](https://travis-ci.org/OcelotProject/Ocelot.svg?branch=master)](https://travis-ci.org/OcelotProject/Ocelot)
* Windows build status: [![Build status](https://ci.appveyor.com/api/projects/status/ahjg5spf83lsu2vn/branch/master?svg=true)](https://ci.appveyor.com/project/cmutel/ocelot/branch/master)
* Test coverage: [![Coverage Status](https://coveralls.io/repos/github/OcelotProject/Ocelot/badge.svg?branch=master)](https://coveralls.io/github/OcelotProject/Ocelot?branch=master)
